@@ -111,7 +111,9 @@ AceLavaanGroup <-
     c2 := c * c                           #Declare c^2 for easy point and variance estimation.
   ")
 
-    # If the A/C component's excluded: (1) overwrite the code and (2) declare a2/c2, so the parameter value can be retrieved later without if statements.
+    # If the A/C component's excluded:
+    # (1) overwrite the code and (2) declare a2/c2,
+    # so the parameter value can be retrieved later without if statements.
     if (!estimateA) modelA <- "\n a2 := 0 \n"
     if (!estimateC) modelC <- "\n c2 := 0 \n"
 
@@ -146,7 +148,8 @@ AceLavaanGroup <-
     #   layer(geom="line") + layer(geom="text") + scale_x_reverse(limits=c(1,0))
 
     components <- base::as.numeric(base::cbind(a2, c2, e2)[1, ] / (a2 + c2 + e2)) # The 'as.numeric' gets rid of the vector labels.
-    if (printOutput) base::print(components) # Print the unity-SCALED ace components.
+    # Print the unity-SCALED ace components.
+    if (printOutput) base::print(components)
     caseCount <- base::nrow(dsClean)
     details <- base::list(lavaan = fit)
     # print(paste("R Levels excluded:",  stringr::str_c(rLevelsToExclude, collapse=", "), "; R Levels retained:", rString)) #Print the dropped & retained groups.
